<?xml version="1.0" ?><!DOCTYPE TS><TS language="da_DK" version="2.1">
<context>
    <name>AppearanceWidget</name>
    <message>
        <location filename="../PAppearanceWidget.ui" line="14"/>
        <source>Appearance</source>
        <translation>Udseende</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="25"/>
        <source>PageEdit</source>
        <translation>PageEdit</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="31"/>
        <location filename="../PAppearanceWidget.ui" line="263"/>
        <source>Fonts:</source>
        <translation>Skrifttyper:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="40"/>
        <source>If no font is specified in the CSS for your page, the following font will be used to display within PageEdit. These fonts will not be used in your actual ebook.</source>
        <translation>Er ingen skrifttyper angivet i den tilhørende CSS-fil, vil følgende skrifttype blive brugt til at vise teksten i &apos;PageEdit&apos;. Skrifterne vil ikke blive anvendt i den endelige bog.</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="70"/>
        <source>Default font size to be used for PageEdit
if no font-size specified in your CSS</source>
        <translation>Standardskriftstørrelse, der skal bruges til PageEdit
hvis der ikke er angivet nogen skriftstørrelse i CSS</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="74"/>
        <location filename="../PAppearanceWidget.ui" line="323"/>
        <source>Font Size:</source>
        <translation>Skriftstørrelse:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="81"/>
        <source>Default font family to be used for PageEdit
if no font-family specified in your CSS</source>
        <translation>Standardskrifttypefamilie, der skal bruges til PageEdit
hvis der ikke er angivet nogen skrifttypefamilie i CSS</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="85"/>
        <source>Standard:</source>
        <translation>Standard:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="108"/>
        <source>Default font family to be used for PageEdit
if a serif font-family specified in your CSS</source>
        <translation>Standardskrifttypefamilie, der skal bruges til PageEdit
hvis der er angivet en serif-skrifttypefamilie i CSS</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="112"/>
        <source>Serif:</source>
        <translation>Serif:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="125"/>
        <source>Default font family to be used for PageEdit
if a sans-serif font-family specified in your CSS</source>
        <translation>Standardskrifttypefamilie, der skal bruges til PageEdit
hvis der er angivet en sans-serif-skrifttypefamilie i CSS</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="129"/>
        <source>Sans-Serif:</source>
        <translation>Sans-Serif:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="156"/>
        <source>Make PageEdit simulate a dark appearance in dark mode</source>
        <translation>Lad PageEdit simulere mørkt udseende i mørk tilstand</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="181"/>
        <source>Main UI</source>
        <translation>Primær UI</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="187"/>
        <source>Main Menu Icon Size:</source>
        <translation>Størrelse på hovedmenuikon:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="193"/>
        <source>Adjust the size of the icons in the main menu.</source>
        <translation>Tilpas størrelsen på ikoner i hovedmenuen.</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="231"/>
        <source>High DPI Setting:</source>
        <translation>Indstillinger højkvalitetsopløsning:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="240"/>
        <source>(Needs PageEdit Restart)</source>
        <translation>(Kræver genstart af PageEdit)</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="269"/>
        <source>UI Font:</source>
        <translation>UI skrifttype:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="279"/>
        <source>Change the font used by PageEdit&apos;s menus, buttons, etc...</source>
        <translation>Skift skrifttype for PageEdits menuer, knapper osv. …</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="282"/>
        <source>Change Font (Needs PageEdit Restart)</source>
        <translation>Skift skrifttype (Kræver genstart af PageEdit)</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="306"/>
        <source>Insert Special Characters:</source>
        <translation>Indsæt specialtegn:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="320"/>
        <source>Font size to be used for Insert Special Characters window</source>
        <translation>Skriftstørrelse, der skal anvendes ved Indsæt specialtegnsvinduet</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="353"/>
        <source>Font family to be used for Insert Special Characters window</source>
        <translation>Skrifttype, der skal anvendes ved Indsæt specialtegnsvinduet</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="356"/>
        <source>Standard Font:</source>
        <translation>Standardskrifttype:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="423"/>
        <source>Reset all fonts and colors to the default values</source>
        <translation>Nulstil alle skrifttyper og farver til standardværdierne</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="426"/>
        <source>Reset All</source>
        <translation>Nulstil alt</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="49"/>
        <location filename="../AppearanceWidget.cpp" line="50"/>
        <source>Detect</source>
        <translation>Undersøg</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="49"/>
        <location filename="../AppearanceWidget.cpp" line="52"/>
        <source>On</source>
        <translation>Valgt</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="49"/>
        <location filename="../AppearanceWidget.cpp" line="54"/>
        <source>Off</source>
        <translation>Fra</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="50"/>
        <source>Detect whether any high dpi scaling should take place.</source>
        <translation>Undersøg om der skal foretages optimering af høj opløsninger.</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="51"/>
        <source>Defers to any Qt environment variables that are set to control high dpi behavior.</source>
        <translation>Brug alle Qt-miljøvariabler, som er sat til at kontrollere High-DPI opførsel.</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="52"/>
        <source>Turns on high dpi scaling and ignores any Qt environment variables</source>
        <translation>Brug High-DPI skalering og ignorer Qt-miljøvariabler</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="53"/>
        <source>that are set controlling high dpi behavior.</source>
        <translation>som er sat til at styre High-DPI opførsel.</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="54"/>
        <source>Turns off high dpi scaling regardless if any Qt environment</source>
        <translation>Slå High-DPI skalering fra, uanset om der er sat</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="55"/>
        <source>variables controlling high dpi behavior are set.</source>
        <translation>nogen Qt-miljøvariabler til styring af High-DPI opførsel.</translation>
    </message>
</context>
<context>
    <name>GeneralSettings</name>
    <message>
        <location filename="../PGeneralSettings.ui" line="14"/>
        <source>General Settings</source>
        <translation>Generelle indstillinger</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="37"/>
        <source>You must restart PageEdit after changing the User Interface language.

If a translation for specific word or phrase is not available it will be displayed in English.</source>
        <translation>Du skal genstarte PageEdit efter at have skiftet brugefladesprog.

Hvis en oversættelse for et ord eller en frase ikke findes, vil det blive vist på engelsk.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="42"/>
        <source>User Interface Language:</source>
        <translation>Brugergrænsefladesprog:</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="74"/>
        <source>Select from installed spellcheck dictionaries.</source>
        <translation>Vælg mellem installerede stavekontrol-ordbøger.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="77"/>
        <source>Spellcheck Dictionary:</source>
        <translation>Ordbog til stavekontrol:</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="119"/>
        <source>Determine if html files are allowed to access non-multimedia remote resources.</source>
        <translation>Vælg, om html-filer har lov til at tilgå ikke-multimedia eksterne ressourcer.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="122"/>
        <source> Control access by html files to non-multimedia remote resources.</source>
        <translation> Kontroller adgang for html-filer til ikke-multimedia eksterne ressourcer.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="131"/>
        <source>Check to allow html files to access non-multimedia remote resources.</source>
        <translation>Afmærk for at tillade html-filer at tilgå ikke-multimedia eksterne ressourcer.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="134"/>
        <source>Html files may access all remote resources types.</source>
        <translation>Html-filer kan tilgå alle eksterne ressource-typer.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="161"/>
        <source>Determine if javascript is allowed to be used by html files</source>
        <translation>Vælg, om html-filer kan anvende javascript</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="164"/>
        <source> Control use of javascript by html files.</source>
        <translation> Kontroller brug af javascript i html-filer.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="173"/>
        <source>Check to allow html files to use javascript.</source>
        <translation>Afmærk for at tillade html-filer at bruge javascript.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="176"/>
        <source>Html files may use javascript.</source>
        <translation>Html-filer kan bruge javascript.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="204"/>
        <source>Choose how you would like PageEdit to handle the use of multiple white space characters during editing.</source>
        <translation>Vælg, hvordan PageEdit skal håndtere flere sammenhængende blanktegn.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="207"/>
        <source>Handle multiple white space layout using:</source>
        <translation>Håndter flere blanktegn ved at:</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="213"/>
        <source>Use CSS white-space: pre-wrap</source>
        <translation>Bruge CSS &apos;white-space: pre-wrap&apos;</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="216"/>
        <source>css white-space: pre-wrap</source>
        <translation>css white-space: pre-wrap</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="226"/>
        <source>Use non-breaking spaces as needed</source>
        <translation>Brug non-breaking spaces efter behov</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="229"/>
        <source>non-breaking spaces as needed</source>
        <translation>non-breaking spaces efter behov</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="257"/>
        <source>Determine if Prettify is used when saving</source>
        <translation>Vælg, om Prettify skal benyttes, når der gemmes</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="260"/>
        <source> Use Prettify to reformat the xhtml when saving.</source>
        <translation> Benyt Prettify til opsætning af xhtml-kode, når der gemmes.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="269"/>
        <source>Check to reformat with Prettify when saving xhtml files.</source>
        <translation>Afmærk for at benytte Prettify, når der gemmes xhtml-filer.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="272"/>
        <source>Use Prettify to reformat xhtml when saving.</source>
        <translation>Benyt Prettify til opsætning af xhtml-kode, når der gemmes.</translation>
    </message>
</context>
<context>
    <name>Inspector</name>
    <message>
        <location filename="../Inspector.cpp" line="74"/>
        <source>Inspect Page or Element</source>
        <translation>undersøg side eller element</translation>
    </message>
    <message>
        <location filename="../Inspector.cpp" line="156"/>
        <source>The Inspector functionality is not supported before Qt 5.11</source>
        <translation>Inspector-funktionen understøttes først fra Qt 5.11</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main.ui" line="15"/>
        <location filename="../MainWindow.cpp" line="1012"/>
        <location filename="../MainWindow.cpp" line="1073"/>
        <location filename="../MainWindow.cpp" line="1764"/>
        <location filename="../MainWindow.cpp" line="1777"/>
        <location filename="../MainWindow.cpp" line="1783"/>
        <location filename="../MainWindow.cpp" line="1797"/>
        <location filename="../MainWindow.cpp" line="1810"/>
        <location filename="../MainWindow.cpp" line="1818"/>
        <location filename="../MainWindow.cpp" line="1873"/>
        <location filename="../MainWindow.cpp" line="1960"/>
        <source>PageEdit</source>
        <translation>PageEdit</translation>
    </message>
    <message>
        <location filename="../main.ui" line="62"/>
        <source>&amp;File</source>
        <translation>&amp;Filer</translation>
    </message>
    <message>
        <location filename="../main.ui" line="75"/>
        <source>&amp;Edit</source>
        <translation>&amp;Rediger</translation>
    </message>
    <message>
        <location filename="../main.ui" line="88"/>
        <source>&amp;Find</source>
        <translation>&amp;Find</translation>
    </message>
    <message>
        <location filename="../main.ui" line="95"/>
        <source>&amp;Insert</source>
        <translation>&amp;Indsæt</translation>
    </message>
    <message>
        <location filename="../main.ui" line="110"/>
        <source>For&amp;mat</source>
        <translation>For&amp;mat</translation>
    </message>
    <message>
        <location filename="../main.ui" line="115"/>
        <source>&amp;Heading</source>
        <translation>&amp;Overskrift</translation>
    </message>
    <message>
        <location filename="../main.ui" line="130"/>
        <source>C&amp;hange Case</source>
        <translation>&amp;Skift mellem store og små bogstaver</translation>
    </message>
    <message>
        <location filename="../main.ui" line="160"/>
        <source>&amp;View</source>
        <translation>&amp;Vis</translation>
    </message>
    <message>
        <location filename="../main.ui" line="169"/>
        <source>Inspector</source>
        <translation>Inspector</translation>
    </message>
    <message>
        <location filename="../main.ui" line="185"/>
        <source>File</source>
        <translation>Fil</translation>
    </message>
    <message>
        <location filename="../main.ui" line="199"/>
        <source>Edit</source>
        <translation>Redigér</translation>
    </message>
    <message>
        <location filename="../main.ui" line="217"/>
        <location filename="../main.ui" line="1157"/>
        <source>Mode</source>
        <translation>Tilstand</translation>
    </message>
    <message>
        <location filename="../main.ui" line="230"/>
        <source>Insert</source>
        <translation>Indsæt</translation>
    </message>
    <message>
        <location filename="../main.ui" line="249"/>
        <source>Inspect</source>
        <translation>Undersøg</translation>
    </message>
    <message>
        <location filename="../main.ui" line="262"/>
        <location filename="../main.ui" line="1106"/>
        <source>Find</source>
        <translation>Søg</translation>
    </message>
    <message>
        <location filename="../main.ui" line="275"/>
        <source>Heading</source>
        <translation>Overskrift</translation>
    </message>
    <message>
        <location filename="../main.ui" line="289"/>
        <source>set Heading Level of Selected Text</source>
        <translation>Angiv overskriftsniveau for valgt tekst</translation>
    </message>
    <message>
        <location filename="../main.ui" line="303"/>
        <source>Change Case</source>
        <translation>Skift mellem store og små bogstaver</translation>
    </message>
    <message>
        <location filename="../main.ui" line="319"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../main.ui" line="337"/>
        <source>Align</source>
        <translation>Justér</translation>
    </message>
    <message>
        <location filename="../main.ui" line="353"/>
        <source>Indent</source>
        <translation>Indryk</translation>
    </message>
    <message>
        <location filename="../main.ui" line="367"/>
        <source>Navigate</source>
        <translation>Navigér</translation>
    </message>
    <message>
        <location filename="../main.ui" line="377"/>
        <source>Navigation List</source>
        <translation>Navigations-liste</translation>
    </message>
    <message>
        <location filename="../main.ui" line="393"/>
        <source>&amp;Save</source>
        <translation>&amp;Gem</translation>
    </message>
    <message>
        <location filename="../main.ui" line="396"/>
        <source>Save the current file.</source>
        <translation>Gem aktuel fil.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="399"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../main.ui" line="409"/>
        <source>&amp;Print</source>
        <translation>&amp;Udskriv</translation>
    </message>
    <message>
        <location filename="../main.ui" line="412"/>
        <source>Print the current Page.</source>
        <translation>Udskriv denne side.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="415"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../main.ui" line="421"/>
        <source>Save &amp;As...</source>
        <translation>Ge&amp;m som …</translation>
    </message>
    <message>
        <location filename="../main.ui" line="424"/>
        <source>Save the current file with a different filename.</source>
        <translation>Gem aktuel fil med et andet filnavn.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="427"/>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <location filename="../main.ui" line="437"/>
        <source>Cu&amp;t</source>
        <translation>&amp;Klip</translation>
    </message>
    <message>
        <location filename="../main.ui" line="440"/>
        <source>Cuts the selected text from the document and puts it on the clipboard.</source>
        <translation>Klipper den valgte tekst fra dokumentet og indsætter det i udklipsholderen.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="450"/>
        <source>&amp;Paste</source>
        <translation>Sæt i&amp;nd</translation>
    </message>
    <message>
        <location filename="../main.ui" line="453"/>
        <source>Pastes the content from the clipboard into the file.</source>
        <translation>Indsætter indholdet af udklipsholder i filen.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="463"/>
        <source>&amp;Undo</source>
        <translation>Fortr&amp;yd</translation>
    </message>
    <message>
        <location filename="../main.ui" line="466"/>
        <source>Reverts the changes of the previous operation.</source>
        <translation>Fortryder den seneste ændring.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="469"/>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <location filename="../main.ui" line="479"/>
        <source>&amp;Redo</source>
        <translation>G&amp;endan</translation>
    </message>
    <message>
        <location filename="../main.ui" line="482"/>
        <source>Restores the changes reverted by the previous Undo action.</source>
        <translation>Gendanner de ændringer, der blev slettet ved sidste Fortryd-handling.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="485"/>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <location filename="../main.ui" line="495"/>
        <source>&amp;Copy</source>
        <translation>K&amp;opiér</translation>
    </message>
    <message>
        <location filename="../main.ui" line="498"/>
        <source>Copies the selected text and puts it on the clipboard.</source>
        <translation>Kopierer den valgte tekst og indsætter den i udklipsholderen.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="511"/>
        <source>Align &amp;Left</source>
        <translation>Justér til &amp;venstre</translation>
    </message>
    <message>
        <location filename="../main.ui" line="514"/>
        <source>Align the paragraph to the left.</source>
        <translation>Venstrejuster aktuelt afsnit.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="528"/>
        <source>Align &amp;Right</source>
        <translation>Justér til &amp;højre</translation>
    </message>
    <message>
        <location filename="../main.ui" line="531"/>
        <source>Align the paragraph to the right.</source>
        <translation>Højrejuster aktuelt afsnit.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="544"/>
        <source>&amp;Center</source>
        <translation>&amp;Centrér</translation>
    </message>
    <message>
        <location filename="../main.ui" line="547"/>
        <source>Center the paragraph.</source>
        <translation>Centrer aktuelt afsnit.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="550"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../main.ui" line="563"/>
        <source>&amp;Justify</source>
        <translation>&amp;Lige margen</translation>
    </message>
    <message>
        <location filename="../main.ui" line="566"/>
        <source>Align the paragraph to both the left and right margins.</source>
        <translation>Juster aktuelt afsnit med lige margener.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="569"/>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <location filename="../main.ui" line="582"/>
        <source>&amp;Bold</source>
        <translation>&amp;Fed</translation>
    </message>
    <message>
        <location filename="../main.ui" line="585"/>
        <source>Make the selected text bold.</source>
        <translation>Gør markeret tekst fed.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="588"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location filename="../main.ui" line="601"/>
        <source>&amp;Italic</source>
        <translation>&amp;Kursiv</translation>
    </message>
    <message>
        <location filename="../main.ui" line="604"/>
        <source>Make the selected text italic.</source>
        <translation>Gør markeret tekst kursiv.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="607"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../main.ui" line="617"/>
        <source>&amp;Open...</source>
        <translation>Å&amp;bn …</translation>
    </message>
    <message>
        <location filename="../main.ui" line="620"/>
        <source>Open a file from disk.</source>
        <translation>Åbn en fil.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="623"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../main.ui" line="636"/>
        <source>&amp;Underline</source>
        <translation>&amp;Understreget</translation>
    </message>
    <message>
        <location filename="../main.ui" line="639"/>
        <source>Underline the selected text.</source>
        <translation>Understreg den valgte tekst.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="642"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../main.ui" line="652"/>
        <source>&amp;Lowercase</source>
        <translation>S&amp;må bogstaver</translation>
    </message>
    <message>
        <location filename="../main.ui" line="655"/>
        <source>Set selected text to lowercase.</source>
        <translation>Gør valgt tekst til små bogstaver.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="658"/>
        <source>Alt+L</source>
        <translation>Alt+L</translation>
    </message>
    <message>
        <location filename="../main.ui" line="668"/>
        <source>&amp;Uppercase</source>
        <translation>S&amp;tore bogstaver</translation>
    </message>
    <message>
        <location filename="../main.ui" line="671"/>
        <source>Set selected text to uppercase.</source>
        <translation>Gør valgt tekst til versaler.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="674"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../main.ui" line="684"/>
        <source>&amp;Titlecase</source>
        <translation>&amp;Titlecase</translation>
    </message>
    <message>
        <location filename="../main.ui" line="687"/>
        <source>Capitalize the first letter of each word selected.</source>
        <translation>Gør det første bogstav i de valgte ord til en versal.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="697"/>
        <source>&amp;Capitalize</source>
        <translation>&amp;Skriv med stort</translation>
    </message>
    <message>
        <location filename="../main.ui" line="700"/>
        <source>Capitalize only the first word of the selected text.</source>
        <translation>Gør det første ord i den valgte tekst til versaler.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="710"/>
        <source>&amp;Quit</source>
        <translation>&amp;Afslut</translation>
    </message>
    <message>
        <location filename="../main.ui" line="713"/>
        <source>Quit</source>
        <translation>Afslut</translation>
    </message>
    <message>
        <location filename="../main.ui" line="716"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../main.ui" line="726"/>
        <source>&amp;Special Character...</source>
        <translation>&amp;Specialtegn …</translation>
    </message>
    <message>
        <location filename="../main.ui" line="729"/>
        <source>Select a character to insert into your text.</source>
        <translation>Vælg et tegn til at indsætte i din tekst.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="742"/>
        <source>&amp;Numbered List</source>
        <translation>&amp;Talopstilling</translation>
    </message>
    <message>
        <location filename="../main.ui" line="745"/>
        <source>Create a numbered list from selection.</source>
        <translation>Opret en talopstilling fra den valgte tekst.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="758"/>
        <source>Bulle&amp;ted List</source>
        <translation>&amp;Punktopstilling</translation>
    </message>
    <message>
        <location filename="../main.ui" line="761"/>
        <source>Create a bulleted list from selection.</source>
        <translation>Opret en punktopstilling fra den valgte tekst.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="764"/>
        <source>Ctrl+Shift+L</source>
        <translation>Ctrl+Shift+L</translation>
    </message>
    <message>
        <location filename="../main.ui" line="777"/>
        <source>Stri&amp;kethrough</source>
        <translation>&amp;Gennemstreget</translation>
    </message>
    <message>
        <location filename="../main.ui" line="780"/>
        <source>Draw a line through the selected text.</source>
        <translation>Gennemstreg den valgte tekst.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="793"/>
        <source>&amp;Subscript</source>
        <translation>&amp;Sænket skrift</translation>
    </message>
    <message>
        <location filename="../main.ui" line="796"/>
        <source>Set the selected text slightly smaller and below the normal line.</source>
        <translation>Gør den valgte tekst lidt mindre og sænket under den normale linje.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="809"/>
        <source>Su&amp;perscript</source>
        <translation>H&amp;ævet skrift</translation>
    </message>
    <message>
        <location filename="../main.ui" line="812"/>
        <source>Set the selected text slightly smaller and above the normal line.</source>
        <translation>Gør den valgte tekst lidt mindre og hævet over den normale linje.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="823"/>
        <source>Zoom &amp;In</source>
        <translation>Zoom &amp;ind</translation>
    </message>
    <message>
        <location filename="../main.ui" line="826"/>
        <source>Zoom In</source>
        <translation>Zoom ind</translation>
    </message>
    <message>
        <location filename="../main.ui" line="829"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../main.ui" line="840"/>
        <source>Zoom &amp;Out</source>
        <translation>Zoom &amp;ud</translation>
    </message>
    <message>
        <location filename="../main.ui" line="843"/>
        <source>Zoom Out</source>
        <translation>Zoom ud</translation>
    </message>
    <message>
        <location filename="../main.ui" line="846"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../main.ui" line="857"/>
        <source>Incre&amp;ase Indent</source>
        <translation>For&amp;øg indrykning</translation>
    </message>
    <message>
        <location filename="../main.ui" line="860"/>
        <source>Increase the indent level of the paragraph.</source>
        <translation>Forøg aktuelt afsnits indrykning.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="863"/>
        <source>Ctrl+Alt+M</source>
        <translation>Ctrl+Alt+M</translation>
    </message>
    <message>
        <location filename="../main.ui" line="873"/>
        <source>&amp;Decrease Indent</source>
        <translation>For&amp;mindsk indrykning</translation>
    </message>
    <message>
        <location filename="../main.ui" line="876"/>
        <source>Decrease the indent level of the paragraph.</source>
        <translation>Formindsk aktuelt afsnits indrykning.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="879"/>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
    <message>
        <location filename="../main.ui" line="889"/>
        <source>Split &amp;Marker</source>
        <translation>Opdelings&amp;markør</translation>
    </message>
    <message>
        <location filename="../main.ui" line="892"/>
        <source>Insert Sigil split file marker</source>
        <translation>Indsæt Sigil-opdelingsmarkør</translation>
    </message>
    <message>
        <location filename="../main.ui" line="895"/>
        <source>Ctrl+Shift+Return</source>
        <translation>Ctrl+Shift+Enter</translation>
    </message>
    <message>
        <location filename="../main.ui" line="901"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;Indstillinger …</translation>
    </message>
    <message>
        <location filename="../main.ui" line="904"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../main.ui" line="910"/>
        <source>&amp;Zoom Reset</source>
        <translation>Nulstil &amp;zoom</translation>
    </message>
    <message>
        <location filename="../main.ui" line="913"/>
        <source>Zoom Reset</source>
        <translation>Nulstil zoom</translation>
    </message>
    <message>
        <location filename="../main.ui" line="916"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../main.ui" line="929"/>
        <source>Heading &amp;1</source>
        <translation>Overskrift &amp;1</translation>
    </message>
    <message>
        <location filename="../main.ui" line="932"/>
        <source>Format paragraph as a level 1 heading.</source>
        <translation>Formatter aktuelt afsnit som niveau 1-overskrift.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="935"/>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <location filename="../main.ui" line="948"/>
        <source>Heading &amp;2</source>
        <translation>Overskrift &amp;2</translation>
    </message>
    <message>
        <location filename="../main.ui" line="951"/>
        <source>Format paragraph as a level 2 heading.</source>
        <translation>Formatter aktuelt afsnit som niveau 2-overskrift.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="954"/>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <location filename="../main.ui" line="967"/>
        <source>Heading &amp;3</source>
        <translation>Overskrift &amp;3</translation>
    </message>
    <message>
        <location filename="../main.ui" line="970"/>
        <source>Format paragraph as a level 3 heading.</source>
        <translation>Formatter aktuelt afsnit som niveau 3-overskrift.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="973"/>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <location filename="../main.ui" line="987"/>
        <source>Heading &amp;4</source>
        <translation>Overskrift &amp;4</translation>
    </message>
    <message>
        <location filename="../main.ui" line="990"/>
        <source>Format paragraph as a level 4 heading.</source>
        <translation>Formatter aktuelt afsnit som niveau 4-overskrift.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="993"/>
        <source>Ctrl+4</source>
        <translation>Ctrl+4</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1006"/>
        <source>Heading &amp;5</source>
        <translation>Overskrift &amp;5</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1009"/>
        <source>Format paragraph as a level 5 heading.</source>
        <translation>Formatter aktuelt afsnit som niveau 5-overskrift.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1012"/>
        <source>Ctrl+5</source>
        <translation>Ctrl+5</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1025"/>
        <source>Heading &amp;6</source>
        <translation>Overskrift &amp;6</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1028"/>
        <source>Format paragraph as a level 6 heading.</source>
        <translation>Formatter aktuelt afsnit som niveau 6-overskrift.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1031"/>
        <source>Ctrl+6</source>
        <translation>Ctrl+6</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1045"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1048"/>
        <source>ormat paragraph as a normal paragraph.</source>
        <translation>Formatter afsnit som almindeligt afsnit.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1051"/>
        <source>Ctrl+7</source>
        <translation>Ctrl+7</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1061"/>
        <source>&amp;Preserve Existing Attributes</source>
        <translation>&amp;Bevar eksisterende attributter</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1064"/>
        <source>When applying this style, preserve any existing attributes on the tag</source>
        <translation>Ved anvendelse af denne typografi, skal alle eksisterende attributter på tagget bevares</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1074"/>
        <source>&amp;Select All</source>
        <translation>&amp;Vælg alt</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1077"/>
        <source>Select all text in the document.</source>
        <translation>Vælg al tekst i dokumentet.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1080"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1090"/>
        <source>&amp;Inspector</source>
        <translation>&amp;Inspector</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1093"/>
        <source>Inspect the page.</source>
        <translation>Undersøg siden.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1096"/>
        <source>Ctrl+F5</source>
        <translation>Ctrl+F5</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1109"/>
        <source>Find text in the page</source>
        <translation>Find tekst på siden</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1112"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1125"/>
        <source>Next XHtml File</source>
        <translation>Næste xhtml-fil</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1128"/>
        <source>Next file in navigation list</source>
        <translation>Næste fil i navigationslisten</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1141"/>
        <source>Previous XHtml File</source>
        <translation>Forrige xhtml-fil</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1144"/>
        <source>Previous file in navigation list</source>
        <translation>Forrige fil i navigationslisten</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1160"/>
        <source>Toggle between Edit and Preview Modes.</source>
        <translation>Skift mellem Rediger og Forhåndsvisning.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1170"/>
        <source>About...</source>
        <translation>Om …</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1173"/>
        <source>Show information about PageEdit.</source>
        <translation>Vis oplysninger om PageEdit.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1183"/>
        <source>Back to Last Link</source>
        <translation>Tilbage til det sidste Link</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1186"/>
        <source>Return from the last link taken</source>
        <translation>Tilbage fra det sidst fulgte link</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1196"/>
        <source>I&amp;D...</source>
        <translation>&amp;ID …</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1199"/>
        <source>Insert or edit an anchor with an ID name to use as a link target.</source>
        <translation>Indsæt eller rediger et anker med et ID-navn til brug som mål for et hyperlink.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1209"/>
        <source>&amp;Link...</source>
        <translation>&amp;Link …</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1212"/>
        <source>Insert or edit an anchor with a hyperlink to a target.</source>
        <translation>Indsæt eller rediger et anker med et hyperlink til et mål.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1222"/>
        <source>&amp;File...</source>
        <translation>&amp;Fil …</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1225"/>
        <source>Select existing image, video or audio files from your book to insert into the text.</source>
        <translation>Vælg eksisterende billede, video- eller lydfil fra din bog og indsæt den i teksten.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1228"/>
        <source>Ctrl+Shift+I</source>
        <translation>Ctrl+Shift+I</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="750"/>
        <source>File load failed</source>
        <translation>Fejl ved indlæsning af fil</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="751"/>
        <source>File Load Failed</source>
        <translation>Fejl ved indlæsning af fil</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="846"/>
        <source>mode: Preview</source>
        <translation>tilstand: Forhåndsvisning</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="848"/>
        <source>mode: Edit</source>
        <translation>tilstand: Rediger</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1012"/>
        <source>Are you sure you want to open this link in your browser?

%1</source>
        <translation>Er du sikker på, at du vil åbne dette link i din browser?

%1</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1074"/>
        <source>Do you want to save your changes before leaving?</source>
        <translation>Vil du gemme dine ændringer, før du forlader programmet?</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1091"/>
        <source>PageEdit is closing...</source>
        <translation>PageEdit lukker …</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1223"/>
        <location filename="../MainWindow.cpp" line="1224"/>
        <location filename="../MainWindow.cpp" line="1225"/>
        <location filename="../MainWindow.cpp" line="1234"/>
        <location filename="../MainWindow.cpp" line="1235"/>
        <location filename="../MainWindow.cpp" line="1236"/>
        <source>HTML files (*.htm *.html *.xhtml)</source>
        <translation>HTML-filer (*.htm *.html *.xhtml)</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1226"/>
        <source>OPF files (*.opf)</source>
        <translation>OPF-filer (*.opf)</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1227"/>
        <source>All files (*.*)</source>
        <translation>Alle filer (*.*)</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1466"/>
        <source>Save File</source>
        <translation>Gem fil</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1501"/>
        <location filename="../MainWindow.cpp" line="1502"/>
        <location filename="../MainWindow.cpp" line="1514"/>
        <location filename="../MainWindow.cpp" line="1515"/>
        <source>File Save-As Failed!</source>
        <translation>Fil Gem som fejlede!</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1501"/>
        <source>is not writeable</source>
        <translation>er ikke skrivbar</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1510"/>
        <location filename="../MainWindow.cpp" line="1549"/>
        <source>File Saved</source>
        <translation>Filen er gemt</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1540"/>
        <location filename="../MainWindow.cpp" line="1542"/>
        <location filename="../MainWindow.cpp" line="1553"/>
        <location filename="../MainWindow.cpp" line="1554"/>
        <source>File Save Failed!</source>
        <translation>Fil Gem som fejlede!</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1541"/>
        <source>does not exist or is not writeable</source>
        <translation>findes ikke eller kan ikke overskrives</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1570"/>
        <source>Do not show this warning again</source>
        <translation>Vis ikke denne advarsel igen</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1571"/>
        <source>This file may not print the way you expect it to.</source>
        <translation>Denne fil udskrives muligvis ikke som forventet.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1572"/>
        <source>Dark backgrounds and colored text applied with an EPUB&apos;s CSS will print.</source>
        <translation>Mørk baggrund og farvet tekst anvendt med en EPUB&apos;s CSS udskrives.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1573"/>
        <source>Use caution as this can result in a lot of ink being used!</source>
        <translation>Vær forsigtig, da dette kan medføre, at der bruges meget blæk!</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1574"/>
        <source>Use the following Print Preview to see how this file will print.</source>
        <translation>Brug følgende udskriftseksempel for at se, hvordan denne fil udskrives.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1575"/>
        <source>Check the box if you don&apos;t wish to see this warning in the future.</source>
        <translation>Marker afkrydsningsfeltet, hvis du ikke ønsker at se denne advarsel i fremtiden.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1598"/>
        <source>Feature not available before Qt5.12.x</source>
        <translation>Funktion en er ikke tilgængelig før Qt5.12.x</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1660"/>
        <source>File Opened</source>
        <translation>Fil åbnet</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1664"/>
        <source>File Open Failed!</source>
        <translation>Fejl ved åbning af fil!</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1687"/>
        <source>Clipboard contains HTML formatting</source>
        <translation>Klippebordet indeholder HTML formateret kode</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1688"/>
        <source>Do you want to paste clipboard data as plain text?</source>
        <translation>Vil du indsætte klippebords data som almindelig tekst?</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1764"/>
        <source>You must select text before inserting a new id.</source>
        <translation>Du skal vælge en tekst før du indsætter et nyt id.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1777"/>
        <source>ID is invalid - must start with a letter, followed by letter number _ : - or .</source>
        <translation>ID er ugyldigt - skal starte med et bogstav, efterfulgt af bogstav nummer _ : - eller .</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1783"/>
        <source>You cannot insert an id at this position.</source>
        <translation>Du kan ikke indsætte et ID ved denne placering.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1797"/>
        <source>You must select text before inserting a new link.</source>
        <translation>Du skal vælge en tekst før di indsætter et nyt link.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1810"/>
        <source>Link is invalid - cannot contain &apos;&lt;&apos; or &apos;&gt;&apos;</source>
        <translation>Link er ugyldig - kan ikke indeholde &apos;&lt;&apos; eller &apos;&gt;&apos;</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1818"/>
        <source>You cannot insert a link at this position.</source>
        <translation>Du kan ikke indsætte et link ved denne placering.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1829"/>
        <source>Insert File</source>
        <translation>Indsæt fil</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1873"/>
        <source>You cannot insert a media file at this position.</source>
        <translation>Du kan ikke indsætte en mediefil på denne placering.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1961"/>
        <source>Do you want to save any changes before overwriting this file?</source>
        <translation>Vil du gemme evt. ændringer, før du overskriver denne fil?</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../Preferences.ui" line="14"/>
        <source>Preferences</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <location filename="../Preferences.cpp" line="90"/>
        <source>PageEdit</source>
        <translation>PageEdit</translation>
    </message>
    <message>
        <location filename="../Preferences.cpp" line="90"/>
        <source>Changes will take effect when you restart PageEdit.</source>
        <translation>Ændringer vil træde i kraft, når du genstarter PageEdit.</translation>
    </message>
    <message>
        <location filename="../Preferences.cpp" line="152"/>
        <source>Open Preferences Location</source>
        <translation>Åben placering for indstillinger</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../OPFReader.cpp" line="59"/>
        <source>Unable to read OPF file.
Line: %1 Column %2 - %3</source>
        <translation>Kunne ikke læse OPF-fil.
Linje: %1 Kolonne %2 - %3</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="379"/>
        <source>Cannot read file %1:
%2.</source>
        <translation>Kan ikke indlæse filen %1:
%2.</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="560"/>
        <source>PageEdit has encountered a problem.</source>
        <translation>PageEdit er stødt på et problem.</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="561"/>
        <source>PageEdit may need to close.</source>
        <translation>PageEdit vil muligvis lukke ned.</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="863"/>
        <source>About PageEdit</source>
        <translation>Om PageEdit</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="868"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="869"/>
        <source>Build Date</source>
        <translation>Build Date</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="870"/>
        <source>Build Time</source>
        <translation>Build Time</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="871"/>
        <source>Qt Runtime Version</source>
        <translation>Qt Runtime Version</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="872"/>
        <source>Qt Compiled Version</source>
        <translation>Qt Compiled Version</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="873"/>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="874"/>
        <source>Architecture</source>
        <translation>Architecture</translation>
    </message>
</context>
<context>
    <name>SearchToolbar</name>
    <message>
        <location filename="../SearchToolbar.ui" line="36"/>
        <source>Search: </source>
        <translation>Søg: </translation>
    </message>
    <message>
        <location filename="../SearchToolbar.ui" line="55"/>
        <source>Search...</source>
        <translation>Søg …</translation>
    </message>
    <message>
        <location filename="../SearchToolbar.ui" line="88"/>
        <source>&amp;Match Case</source>
        <translation>Forskel på STORE/s&amp;må bogstaver</translation>
    </message>
    <message>
        <location filename="../SearchToolbar.cpp" line="137"/>
        <source>No results found.</source>
        <translation>Intet fundet.</translation>
    </message>
</context>
<context>
    <name>SelectCharacter</name>
    <message>
        <location filename="../SelectCharacter.ui" line="14"/>
        <source>Insert Special Character</source>
        <translation>Indsæt specialtegn</translation>
    </message>
</context>
<context>
    <name>SelectFiles</name>
    <message>
        <location filename="../SelectFiles.ui" line="14"/>
        <source>Insert File</source>
        <translation>Indsæt fil</translation>
    </message>
    <message>
        <location filename="../SelectFiles.ui" line="46"/>
        <source>List only the file names which contain the text you enter.</source>
        <translation>Anfør kun de filnavne, som indeholder den tekst, du indtaster.</translation>
    </message>
    <message>
        <location filename="../SelectFiles.ui" line="49"/>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <location filename="../SelectFiles.ui" line="118"/>
        <source>Thumbnail size:</source>
        <translation>Miniaturestørrelse:</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="113"/>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="114"/>
        <source>Images</source>
        <translation>Billeder</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="115"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="116"/>
        <source>Audio</source>
        <translation>Lyd</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="159"/>
        <source>Media Files In the Book</source>
        <translation>Mediefiler i bogen</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="162"/>
        <source>Thumbnails</source>
        <translation>Miniaturer</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="325"/>
        <source>shades</source>
        <translation>nuancer</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="325"/>
        <source>colors</source>
        <translation>farver</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="326"/>
        <source>Grayscale</source>
        <translation>Gråskala</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="326"/>
        <source>Color</source>
        <translation>Farve</translation>
    </message>
</context>
<context>
    <name>SelectHyperlink</name>
    <message>
        <location filename="../SelectHyperlink.ui" line="14"/>
        <source>Select Target</source>
        <translation>Vælg mål</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.ui" line="22"/>
        <source>List only the entries that match the text you enter.</source>
        <translation>Vis kun angivelserne, der matcher den tekst, du indtaster.</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.ui" line="25"/>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.ui" line="58"/>
        <source>Enter the target URL for this hyperlink.  You can select or 
double click on existing destinations in your book from the list above.</source>
        <translation>Indtast mål-URL&apos;et for dette hyperlink.  Du kan vælge eller
dobbeltklikke på eksisterende destinationer i din bog fra listen ovenfor.</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.ui" line="62"/>
        <source>Target:</source>
        <translation>Mål:</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.cpp" line="94"/>
        <source>Targets in the Book</source>
        <translation>Mål i bogen</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.cpp" line="95"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
</context>
<context>
    <name>SelectId</name>
    <message>
        <location filename="../SelectId.ui" line="14"/>
        <source>Insert ID </source>
        <translation>Indsæt ID </translation>
    </message>
    <message>
        <location filename="../SelectId.ui" line="22"/>
        <source>Enter an ID name to use as a destination for hyperlinks, notes, and TOC entries.

The dropdown box shows existing ID names in the current file.

ID names must be unique and start with a letter.</source>
        <translation>Indtast et ID-navn til at bruge som en destination for hyperlinks, noter og indholdsfortegnelsesindtastninger.

Rullemenuboksen viser eksisterende ID-navne i den aktuelle fil.

ID skal være unikke og starte med et bogstav.</translation>
    </message>
    <message>
        <location filename="../SelectId.ui" line="29"/>
        <source>ID:</source>
        <translation>ID:</translation>
    </message>
</context>
<context>
    <name>Utility</name>
    <message>
        <location filename="../Utility.cpp" line="656"/>
        <source>PageEdit</source>
        <translation>PageEdit</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="657"/>
        <source>The requested file name contains non-ASCII characters. You should only use ASCII characters in filenames. Using non-ASCII characters can prevent the EPUB from working with some readers.

Continue using the requested filename?</source>
        <translation>Det ønskede filnavn indeholder ikke-ASCII-tegn. Du bør kun bruge ASCII-tegn i filnavne. Brug af ikke-ASCII-tegn kan forhindre EPUB i at fungere på nogle læsere.

Fortsæt med at bruge det ønskede filnavn?</translation>
    </message>
</context>
<context>
    <name>WebViewEdit</name>
    <message>
        <location filename="../WebViewEdit.cpp" line="167"/>
        <source>No suggestions</source>
        <translation>Ingen forslag</translation>
    </message>
    <message>
        <location filename="../WebViewEdit.cpp" line="179"/>
        <source>Check Spelling</source>
        <translation>Kontroller stavning</translation>
    </message>
    <message>
        <location filename="../WebViewEdit.cpp" line="188"/>
        <source>Select Language</source>
        <translation>Vælg sprog</translation>
    </message>
</context>
</TS>